==> homesitemaker-v0.4.2.tar.gz: homesitemaker/includes/languages/spanish/homesite-album.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/


//---------- ./homesite/info.php ----------

// Headline Row (HR)
$TEXT001="Lista Actual de Albums";
$TEXT002="Enviar Album";
$TEXT003="T&iacute;tulo del Album";
$TEXT004="Descripci&oacute;n";
$TEXT005="Fotos";
$TEXT006="Autor";
$TEXT007="Fecha";
$TEXT008="Anterior";
$TEXT009="Siguiente";
$TEXT010="Total";
$TEXT011="Secci&oacute;n de Album de Fotos";
$TEXT012="T&iacute;tulo del Album: ";
$TEXT013="Editar Album: ";
$TEXT014="alta";
$TEXT015="media";
$TEXT016="baja";
$TEXT017="Eliminar las Seleccionadas";
$TEXT018="Editar";
$TEXT019="A&ntilde;adir Fotos";
$TEXT020="Borrar Album";
$TEXT021="No tienes los permisos suficientes para editar las propiedades del album seleccionado !";
$TEXT022="Fecha de env&iacute;o:";
$TEXT023="Opcional";
$TEXT024="Introduce una breve descripci&oacute;n del album de fotos (max. 255 car&aacute;cteres)";
$TEXT025="Selecciona qui&eacute;n puede verlo: ";
$TEXT026="(Opci&oacute;n por defecto: Todo el mundo)";
$TEXT027="Todo el mundo";
$TEXT028="Usuarios registrados";
$TEXT029="S&oacute;lo una lista de usuarios registrados";
$TEXT030="(Mant&eacute;n pulsada la tecla -Ctrl- para seleccionar varios usuarios simultaneamente)";
$TEXT031="Selecciona qui&eacute;n puede editarlo y a&ntilde;adir o borrar fotos: ";
$TEXT032="Siguiente Paso: Subir las Fotos";
$TEXT033="Publicar";
$TEXT034="Registro de un nuevo album de fotos";
$TEXT035="Paso 2: Selecci&oacute;n de Fotos";
$TEXT036="Selecciona el album al cual quieres a&ntilde;adir las fotos:";

$TEXT037="A&ntilde;ade las fotos de una en una y pulsa en (Paso Siguiente) cuando hayas terminado.<br>".
         "No te preocupes si deseas a&ntilde;adir m&aacute;s fotos, ya que podr&aacute;s a&ntilde;adir cuantas ".
         "quieras una vez que el album ya est&eacute; publicado.";

$TEXT038="Selecciona una foto:";
$TEXT039="Descripci&oacute;n de la Foto:";
$TEXT040="Lista actual de fotos para este album";
$TEXT041="n&uacute;mero de fotos";
$TEXT042="Paso Siguiente: Confirmaci&oacute;n";
$TEXT043="No tienes suficientes permisos para añadir nuevas fotos a este album !";
$TEXT044="Alta de un nuevo album de fotos";
$TEXT045="&Uacute;ltimo Paso";
$TEXT046="Enhorabuena!";
$TEXT047="Todos los datos del albumi, asi como las fotos del mismo, se han recibido correctamente.";

$TEXT048="El album ha sido correctamente publicado.<br><br>".
         "Los usuarios seleccionados podr&aacute;n verlo y/o modificarlo.";

$TEXT049="La siguiente es la lista de albums que est&aacute;n pendientes de tu aprovaci&oacute;n. ".
         "Si puedes ver esta lista, entonces es que dispones de los privilegios suficientes para hacerlo.<br>".
         "Puedes borrar directamente un album pulsando sobre la opci&oacute;n Borrar.<br>".
         "En caso contrario, pulsa sobre el titulo de la noticia que desees editar y/o publicar.";

$TEXT050="Borrar";
$TEXT051="Id.Album";
$TEXT052="Titulo";
$TEXT053="Fecha";
$TEXT054="No hay albums pendientes de publicar.";
$TEXT055="Borrando Album";
$TEXT056="Cuidado asegurate antes de continuar!";
$TEXT057="La siguiente lista de ficheros se borrar&aacute;n:";
$TEXT059="No dispones de privilegios suficientes para borrar este album!";

$TEXT060="Tan s&oacute;lo los usuarios registrados pueden eliminar albums.<br>".
         "Incluso aunque el autor diera acceso completo a su album de fotos.";
?>

==> homesitemaker-v0.4.4.tar.gz: homesitemaker/includes/languages/spanish/homesite-album.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/


//---------- ./homesite/info.php ----------

// Headline Row (HR)
$TEXT001="Lista Actual de Albums";
$TEXT002="Enviar Album";
$TEXT003="T&iacute;tulo del Album";
$TEXT004="Descripci&oacute;n";
$TEXT005="Fotos";
$TEXT006="Autor";
$TEXT007="Fecha";
$TEXT008="Anterior";
$TEXT009="Siguiente";
$TEXT010="Total";
$TEXT011="Secci&oacute;n de Album de Fotos";
$TEXT012="T&iacute;tulo del Album: ";
$TEXT013="Editar Album: ";
$TEXT014="alta";
$TEXT015="media";
$TEXT016="baja";
$TEXT017="Eliminar las Seleccionadas";
$TEXT018="Editar";
$TEXT019="A&ntilde;adir Fotos";
$TEXT020="Borrar Album";
$TEXT021="No tienes los permisos suficientes para editar las propiedades del album seleccionado !";
$TEXT022="Fecha de env&iacute;o:";
$TEXT023="Opcional";
$TEXT024="Introduce una breve descripci&oacute;n del album de fotos (max. 255 car&aacute;cteres)";
$TEXT025="Selecciona qui&eacute;n puede verlo: ";
$TEXT026="(Opci&oacute;n por defecto: Todo el mundo)";
$TEXT027="Todo el mundo";
$TEXT028="Usuarios registrados";
$TEXT029="S&oacute;lo una lista de usuarios registrados";
$TEXT030="(Mant&eacute;n pulsada la tecla -Ctrl- para seleccionar varios usuarios simultaneamente)";
$TEXT031="Selecciona qui&eacute;n puede editarlo y a&ntilde;adir o borrar fotos: ";
$TEXT032="Siguiente Paso: Subir las Fotos";
$TEXT033="Publicar";
$TEXT034="Registro de un nuevo album de fotos";
$TEXT035="Paso 2: Selecci&oacute;n de Fotos";
$TEXT036="Selecciona el album al cual quieres a&ntilde;adir las fotos:";

$TEXT037="A&ntilde;ade las fotos de una en una y pulsa en (Paso Siguiente) cuando hayas terminado.<br>".
         "No te preocupes si deseas a&ntilde;adir m&aacute;s fotos, ya que podr&aacute;s a&ntilde;adir cuantas ".
         "quieras una vez que el album ya est&eacute; publicado.";

$TEXT038="Selecciona una foto:";
$TEXT039="Descripci&oacute;n de la Foto:";
$TEXT040="Lista actual de fotos para este album";
$TEXT041="n&uacute;mero de fotos";
$TEXT042="Paso Siguiente: Confirmaci&oacute;n";
$TEXT043="No tienes suficientes permisos para añadir nuevas fotos a este album !";
$TEXT044="Alta de un nuevo album de fotos";
$TEXT045="&Uacute;ltimo Paso";
$TEXT046="Enhorabuena!";
$TEXT047="Todos los datos del albumi, asi como las fotos del mismo, se han recibido correctamente.";

$TEXT048="El album ha sido correctamente publicado.<br><br>".
         "Los usuarios seleccionados podr&aacute;n verlo y/o modificarlo.";

$TEXT049="La siguiente es la lista de albums que est&aacute;n pendientes de tu aprovaci&oacute;n. ".
         "Si puedes ver esta lista, entonces es que dispones de los privilegios suficientes para hacerlo.<br>".
         "Puedes borrar directamente un album pulsando sobre la opci&oacute;n Borrar.<br>".
         "En caso contrario, pulsa sobre el titulo de la noticia que desees editar y/o publicar.";

$TEXT050="Borrar";
$TEXT051="Id.Album";
$TEXT052="Titulo";
$TEXT053="Fecha";
$TEXT054="No hay albums pendientes de publicar.";
$TEXT055="Borrando Album";
$TEXT056="Cuidado asegurate antes de continuar!";
$TEXT057="La siguiente lista de ficheros se borrar&aacute;n:";
$TEXT059="No dispones de privilegios suficientes para borrar este album!";

$TEXT060="Tan s&oacute;lo los usuarios registrados pueden eliminar albums.<br>".
         "Incluso aunque el autor diera acceso completo a su album de fotos.";
$TEXT061="<br>No tienes permisos suficientes para publicar albums pendientes!<br><br>".
         "Si deseas ser Editor, senvia un email al administrador de la web.<br>&nbsp;";
$TEXT062="Editar Seleccionados";
$TEXT063="Editar comentarios";
$TEXT064="Aplicar Cambios";
$TEXT065="Los siguientes comentarios ser&aacute;n editaos:";
$TEXT066="No has seleccionado ninguna foto!";
?>
